@@ -4,8 +4,8 @@
 */
 
 #include "statustoggle.h"
-#include "themedbackgroundrenderer.h"
 #include "statustogglebutton.h"
+#include "themedbackgroundrenderer.h"
 
 #include <KLocalizedString>
 
@@ -13,8 +13,8 @@
 
 using namespace Practice;
 
-StatusToggle::StatusToggle(QWidget* parent)
-    : ImageWidget(parent), m_renderer(0), m_resultState(AbstractFrontend::QuestionState)
+StatusToggle::StatusToggle(QWidget *parent)
+    : ImageWidget(parent)
 {
     setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     setScalingEnabled(false);
